Optimal subset selection for multivariate transformation models
abess_mmlt(
mltargs,
supp,
k_max = supp,
thresh = NULL,
init = TRUE,
m_max = 10,
m0 = NULL,
...
)List containing the fitted model via mmlt, active set
A and inactive set I.
Arguments passed to mmlt
support size of the coefficient vector
maximum support size to consider during the splicing algorithm.
Defaults to supp.
threshold when to stop splicing. Defaults to
0.01 * supp * p * log(log(n)) / n$, where p denotes the number of predictors
and n the sample size.
initialize active set. Defaults to TRUE and initializes the
active set with those covariates that are most correlated with score residuals
of an unconditional modFUN(update(formula, . ~ 1)).
maximum number of iterating the splicing algorithm.
Transformation model for initialization
Currently ignored