Learn R Programming

tramvs (version 0.0-8)

mmltVS: Select optimal subset based on high dimensional BIC in mmlts

Description

Select optimal subset based on high dimensional BIC in mmlts

Usage

mmltVS(
  mltargs,
  supp_max = NULL,
  k_max = NULL,
  thresh = NULL,
  init = TRUE,
  m_max = 10,
  verbose = TRUE,
  parallel = FALSE,
  m0 = NULL,
  future_args = list(strategy = "multisession", workers = supp_max),
  ...
)

Value

object of class "mltvs", containing the regularization path (information criterion SIC and coefficients coefs), the best fit (best_fit) and all other models (all_fits)

Arguments

mltargs

Arguments passed to mmlt

supp_max

maximum support which to call abess_tram with.

k_max

maximum support size to consider during the splicing algorithm. Defaults to supp.

thresh

threshold when to stop splicing. Defaults to 0.01 * supp * p * log(log(n)) / n$, where p denotes the number of predictors and n the sample size.

init

initialize active set. Defaults to TRUE and initializes the active set with those covariates that are most correlated with score residuals of an unconditional modFUN(update(formula, . ~ 1)).

m_max

maximum number of iterating the splicing algorithm.

verbose

show progress bar (default: TRUE)

parallel

toggle for parallel computing via future_lapply

m0

Transformation model for initialization

future_args

arguments passed to plan; defaults to a "multisession" with supp_max workers

...

Arguments passed on to abess_mmlt

supp

support size of the coefficient vector

Details

L0-penalized (i.e., best subset selection) multivariate transformation models using the abess algorithm.