Select optimal subset based on high dimensional BIC in mmlts
mmltVS(
mltargs,
supp_max = NULL,
k_max = NULL,
thresh = NULL,
init = TRUE,
m_max = 10,
verbose = TRUE,
parallel = FALSE,
m0 = NULL,
future_args = list(strategy = "multisession", workers = supp_max),
...
)object of class "mltvs", containing the regularization path
(information criterion SIC and coefficients coefs), the
best fit (best_fit) and all other models (all_fits)
Arguments passed to mmlt
maximum support which to call abess_tram with.
maximum support size to consider during the splicing algorithm.
Defaults to supp.
threshold when to stop splicing. Defaults to
0.01 * supp * p * log(log(n)) / n$, where p denotes the number of predictors
and n the sample size.
initialize active set. Defaults to TRUE and initializes the
active set with those covariates that are most correlated with score residuals
of an unconditional modFUN(update(formula, . ~ 1)).
maximum number of iterating the splicing algorithm.
show progress bar (default: TRUE)
toggle for parallel computing via
future_lapply
Transformation model for initialization
arguments passed to plan; defaults
to a "multisession" with supp_max workers
Arguments passed on to abess_mmlt
suppsupport size of the coefficient vector
L0-penalized (i.e., best subset selection) multivariate transformation models using the abess algorithm.